<?php


// If this file is called directly, abort.
defined( 'WPINC' ) || die( 'Well, get lost.' );

/**
 * Class WP_Persistent_login
 *
 * @since 2.0.0
 */
class WP_Persistent_Login_Premium extends WP_Persistent_Login {

    /**
	 * Initialize the class and set its properties.
	 *
	 * We register all our common hooks here.
	 *
	 * @since  2.0.0
	 * @access public
	 *
	 * @return void
	 */
	public function __construct() {

		parent::__construct();
		
		// set the expiration time when a user logs in
		add_filter( 'auth_cookie_expiration', array($this, 'persistent_login_set_login_expiration'), 10, 3 );

		add_action( 'init', array($this, 'is_hide_remember_me_enabled') );	

	}


	/**
	 * Adjust the login expiration time if the user selected to be remembered.
	 *
	 * @since  1.0.0
	 * @access public
	 *
	 * @return int $expiration
	 */
	public function persistent_login_set_login_expiration($expiration, $user_id, $remember) {
			
		// the the user wants to be remembered, run our logic
		if( $remember ) :
						
			// default expiration time to 1 year
			$expiration = YEAR_IN_SECONDS;

			if ( persistent_login()->can_use_premium_code() ) :
										
				$persistent_login_premium_options = (array) get_option('persistent_login_options_premium');
				
				// set the expiration time
				if( isset($persistent_login_premium_options) && isset($persistent_login_premium_options['cookieTime']) ) {
					$expiration = $persistent_login_premium_options['cookieTime'];
				}
				
				// check if the users role is selected
				if( isset($persistent_login_premium_options) && !empty($persistent_login_premium_options['roles']) ) {
					
					// fetch the roles data
					$persistent_login_roles = $persistent_login_premium_options['roles']; 

					// fetch the WP_User object
					$user = get_user_by( 'id', $user_id );
												
					// check if the users role is checked for persistent login
					if( is_array($user->roles) ) {
						$role_check = array_intersect($user->roles, $persistent_login_roles);
						if( !empty($role_check) ) {
							$role_check = true;
						} else {
							$role_check = false;
						}
					} else {
						$role_check = in_array($user->roles, $persistent_login_roles);
					}
					
					// if users role isn't selected, then reset to default
					if( $role_check === false ) :									
						// if user isn't in the role, then set expiration to 14 days			
						$expiration = DAY_IN_SECONDS * 14;
					endif;

				}							
												
			endif;
												
		endif;
	  
		/**
		 * Filter hook to change the expiration time manually
		 *
		 * @param int $expiration Expiration time in seconds.
		 * @param int $user_id The current Users ID.
		 * @param bool $remember Boolean value for if the user selected to be remembered.
		 *
		 * @since 1.4.0
		 */
		return apply_filters( 'wp_persistent_login_auth_cookie_expiration', $expiration, $user_id, $remember);
	  
	}

	
	public function is_hide_remember_me_enabled() {

		$settings = new WP_Persistent_Login_Settings_Premium();
		$hide_remember_me = $settings->get_hide_remember_me();

		if( $hide_remember_me === '1' ) {

			add_filter( 'login_footer', array($this, 'hide_remember_me') );	
			add_action( 'wp_footer', array($this, 'hide_remember_me') );

		} else {
		
			return false;
		
		}

	}
	

	/**
	 * hide_remember_me
	 *
	 * @return string
	 */
	public function hide_remember_me() {
		
		echo '<script>';
		echo "
			var wppl_hide_remember_me = function() {
				
				// hide remember me by default
				var forms = document.querySelectorAll('form'); 						
				if (forms) {

					var rememberMeNames = ['rememberme', 'remember', 'rcp_user_remember'];
					var rememberArray = [];

					for( z = 0; z < rememberMeNames.length; z++ ) {
						var rememberMe = document.getElementsByName(rememberMeNames[z]);
						if( rememberMe.length ) {
							rememberArray.push(rememberMe);
						}
					}
					
					// look out for inputs named remember
						var woocommerce = document.querySelectorAll('.woocommerce-form-login__rememberme');
						if( woocommerce.length ) {
							rememberArray.push(woocommerce);
						}					
					
					// if there are remember me inputs
					if( rememberArray.length ) { 	
					
						// hide the inputs
							for (i = 0; i < rememberArray.length; i++) {
								for (x = 0; x < rememberArray[i].length; x++) {

								  	rememberArray[i][x].style.display = 'none';

								  	// hide any labels that are parents of this input
									var label = rememberArray[i][x].closest('label');
									if( label !== null ) {
										label.style.display = 'none';
									}

								}
							}

						
					
					}
					
					// look out for rememberme labels with a name attribute

						var rememberMeLabels = ['rememberme', 'remember', 'rcp_user_remember'];
						var rememberLabelsArray = [];

						for( z = 0; z < rememberMeLabels.length; z++ ) {							
							var rememberMeLabel = document.querySelectorAll('label[for=\"'+ rememberMeLabels[z] +'\"]');
							if( rememberMeLabel.length ) {
								rememberLabelsArray.push(rememberMeLabel);
							}
						}
						
						// if there are remember me inputs
						if( rememberLabelsArray.length ) { 	
						
							// hide the labels
								for (i = 0; i < rememberLabelsArray.length; i++) {
									for (x = 0; x < rememberLabelsArray[i].length; x++) {
										rememberLabelsArray[i][x].style.display = 'none';
									}
								}
						
						}			

					
					// test for Ultimate Member Plugin forms
						
						// find the UM checkboxes
						var UmCheckboxIcon = document.querySelectorAll('.um-icon-android-checkbox-outline-blank');
						var UmCheckboxLabel = document.querySelectorAll('.um-field-checkbox');
						
						if( UmCheckboxIcon.length && UmCheckboxLabel.length ) {
							
							// loop through UM checkboxes
							for (i = 0; i < UmCheckboxLabel.length; i++) {
								
								// find the UM input element
								var UMCheckboxElement = UmCheckboxLabel[i].children;
								var UMCheckboxElementName = UMCheckboxElement[0].getAttribute('name');
								
								// check if UM input element is remember me box
								if( UMCheckboxElementName === 'remember' || UMCheckboxElementName === 'rememberme' ) {
									
									// activate the UM checkbox if it is a remember me box
									UmCheckboxLabel[i].classList.add('active');
									
									// hide the label element 
									UmCheckboxLabel[i].style.display = 'none';
									
									// swap out UM classes to show the active state
									UmCheckboxIcon[i].classList.add('um-icon-android-checkbox-outline');
									UmCheckboxIcon[i].classList.remove('um-icon-android-checkbox-outline-blank');
									
									// hide the checkbox element
									UmCheckboxIcon[i].style.display = 'none';
									
									
								} // endif
							
							} // end for

						} // endif UM
						
					
						
					// test for AR Member Forms
					
						var ArmRememberMeCheckboxContainer = document.querySelectorAll('.arm_form_input_container_rememberme');
						
						if( ArmRememberMeCheckboxContainer.length ) {
							
							for (i = 0; i < ArmRememberMeCheckboxContainer.length; i++) {
								
								var ArmRememberMeCheckbox = ArmRememberMeCheckboxContainer[i].querySelectorAll('md-checkbox');
								
								if( ArmRememberMeCheckbox.length ) {
									// loop through AR Member checkboxes
									for (x = 0; x < ArmRememberMeCheckbox.length; x++) {
										if( ArmRememberMeCheckbox[x].classList.contains('ng-empty') ) {
											ArmRememberMeCheckbox[x].click();
											ArmRememberMeCheckboxContainer[i].style.display = 'none';
										}
									}
								}
								
							}
							
						} // end if AR Member
					
			
				} // endif forms

			}

			document.addEventListener('DOMContentLoaded', function(event) {
				wppl_hide_remember_me();
			});

			";
		echo '</script>';
	}

}

?>