<?php

/**
 * persistent_login_update_db_check
 *
 * @return void
 */
function persistent_login_update_db_check() {
                
    // check db version
    $persistent_login_db_version = WPPL_DATABASE_VERSION;
    $current_persistent_login_db_version = get_option( 'persistent_login_db_version' );
    
    // test db version number against plugin
    if ( $current_persistent_login_db_version !== $persistent_login_db_version) :
    
        // if different, run the update function
        $persistent_login_db_update = persistent_login_update_db($current_persistent_login_db_version);
                        
    endif;
    
    // update premium options
        if ( persistent_login()->is__premium_only() ) :
            if ( persistent_login()->can_use_premium_code() ) :
            
                // check for default premium options, if not set, set to default of 1 year
                    if( !get_option('persistent_login_options_premium') ) :
                        $defaultOptions = array(
                            'cookieTime' => strtotime('1 year', 0), // default to 1 year
                        );
                        update_option('persistent_login_options_premium', $defaultOptions);
                    endif;
                    
            endif;
        endif;

}
add_action( 'plugins_loaded', 'persistent_login_update_db_check' );




/**
 * persistent_login_update_db
 *
 * @param  mixed $persistent_login_db_version
 * @return void
 */
function persistent_login_update_db($persistent_login_db_version) {
    
    // multi-device support
    if( $persistent_login_db_version === '1.1.3' ) :
        // load required global vars
            global $wpdb;
            $tableRef = WPPL_DATABASE_NAME;
        
        // set table name
            $table = $wpdb->prefix . $tableRef;
        
        // fetch charset for db	
            $charset_collate = $wpdb->get_charset_collate();
                        
        // run query					
            $table_update = $wpdb->query( 
                "
                    ALTER TABLE $table 
                    ADD `ip` INT(11) NOT NULL AFTER `login_key`,
                    ADD `user_agent` varchar(255) NOT NULL AFTER `ip`
                "
            );
                
        // update db version option
            update_option( 'persistent_login_db_version', '1.1.3');
            $persistent_login_db_version = '1.1.3';
        
    endif; // 1.1.3 update
    
    // timestamps
    if( $persistent_login_db_version === '1.1.3' ) :
        // load required global vars
            global $wpdb;
            $tableRef = WPPL_DATABASE_NAME;
        
        // set table name
            $table = $wpdb->prefix . $tableRef;
        
        // fetch charset for db	
            $charset_collate = $wpdb->get_charset_collate();
                        
        // run query					
            $table_update = $wpdb->query( 
                "
                    ALTER TABLE $table 
                    ADD `timestamp` CHAR(19) NOT NULL AFTER `user_agent`
                "
            );
                
        // update db version option
            update_option( 'persistent_login_db_version', '1.2.3');
            $persistent_login_db_version = '1.2.3';
            
    endif; // 1.2.3 update
    
        
    // remove db, no longer needed
    if( $persistent_login_db_version === '1.2.3' ) :
        
        // remove all existing logins
            global $wpdb;
            $tableRef = WPPL_DATABASE_NAME;
            $table = $wpdb->prefix . $tableRef;
            
            // drop the table, we don't need it anymore!
            $sql = "DROP TABLE IF EXISTS $table;";
            $drop = $wpdb->query($sql);
            
            if( $drop ) :
                                
                // update db version option
                update_option( 'persistent_login_db_version', '1.3.0');
                $persistent_login_db_version = '1.3.0';
                return true;
                    
            else : 
                
                return false;
                
            endif;
            
    endif; // 1.3.0 update
    
    
    // fixing options in options table
    if( $persistent_login_db_version === '1.3.0' ) :
                    
        // fetching the current settings, which we don't need any more!
        $current_settings = get_option('persistent_login_options_user_access');
        
        if( $current_settings ) : 
            
            // if premium, move the array to persistent_login_options_premium['roles']
            // if not premium, the user doesn't need these options.
            if ( persistent_login()->is__premium_only() ) :
                if ( persistent_login()->can_use_premium_code() ) :
                
                    // fetch all the WP roles, add to a default roles array
                    $roles = wp_roles();
                    $default_roles = array();
                    foreach( $roles->roles as $key=>$value ) :
                        array_push($default_roles, $key);
                    endforeach;
                
                    // create an empty array of chosen toles
                    $chosen_roles = array();
                    
                    // if the current setting is a default role, add it to the list of chosen roles															
                    foreach( $current_settings as $setting ) {
                        $role_check = in_array($setting, $default_roles);
                        if( $role_check ) {
                            array_push($chosen_roles, $setting);
                        } 
                    } 
                                                
                    // assign the chosen roles to the premium settings roles array
                    $premium_settings = get_option('persistent_login_options_premium');
                    $premium_settings['roles'] = $chosen_roles;							
                    
                    // update the option in the db
                    update_option('persistent_login_options_premium', $premium_settings);
                    
                endif;							
            endif;
            
            // now delete the old free option, not needed anymore
            delete_option('persistent_login_options_user_access');
            
            // update db version option
            update_option( 'persistent_login_db_version', '1.3.10');
            $persistent_login_db_version = '1.3.10';
            return true;

        endif;
    
    endif; // 1.3.10 update
    
    
    if( $persistent_login_db_version === '1.3.10' ) :
    
        // Use wp_next_scheduled to check if the event is already scheduled
        $timestamp = wp_next_scheduled( 'persistent_login_user_count' );
    
        // If $timestamp == false schedule daily backups since it hasn't been done previously
        if( $timestamp == false ) {
            // Schedule the event for right now, then to repeat daily using the hook 'persistent_login_user_count'
            wp_schedule_event( time(), 'twicedaily', 'persistent_login_user_count' );
        }
        
        // update db version option
            update_option( 'persistent_login_db_version', '1.3.12');
            $persistent_login_db_version = '1.3.12';
            return true;
        
    endif; // 1.3.12 update
    
    
    if( $persistent_login_db_version === '1.3.12' ) :
    
        $options = get_option('persistent_login_options');

        if( !isset($options['limitActiveLogins']) ) {
            $options['limitActiveLogins'] = '0';
        }
        if( !isset($options['duplicateSessions']) ) {
            $options['duplicateSessions'] = '0';
        }

        update_option('persistent_login_options', $options);

        if ( persistent_login()->is__premium_only() ) :
            if ( persistent_login()->can_use_premium_code() ) :

                $premium_settings = get_option('persistent_login_options_premium');

                if( !isset($premium_settings['activeLoginsAllowed']) ) {
                    $premium_settings['activeLoginsAllowed'] = '1';
                }
                if( !isset($premium_settings['activeLoginRoles']) ) {
                    $premium_settings['activeLoginRoles'] = array();
                }
                if( !isset($premium_settings['maximumLoginsRedirect']) ) {
                    $premium_settings['maximumLoginsRedirect'] = NULL;
                }
                if( !isset($premium_settings['activeLoginLogic']) ) {
                    $premium_settings['activeLoginLogic'] = 'automatic';
                }
                if( !isset($premium_settings['hideRememberMe']) ) {
                    $premium_settings['hideRememberMe'] = '0';
                }

                update_option('persistent_login_options_premium', $premium_settings);
            
            endif;
        endif;
                
        // update db version option
            update_option( 'persistent_login_db_version', '2.0.0');
            $persistent_login_db_version = '2.0.0';
            return true;
        
    endif; // 2.0.0 update
    
    
    if( $persistent_login_db_version === '2.0.0' ) :
    
        if ( persistent_login()->is__premium_only() ) :
            if ( persistent_login()->can_use_premium_code() ) :

                $premium_settings = get_option('persistent_login_options_premium');
                $options = get_option('persistent_login_options');

                if( isset($premium_settings['activeLoginLogic']) ) {

                    // get the current premium setting for active login logic
                    $active_login_logic = $premium_settings['activeLoginLogic'];

                    // delete the premium setting 
                    unset($premium_settings['activeLoginLogic']);

                    // save premium settings without active login logic
                    update_option('persistent_login_options_premium', $premium_settings);
                    
                    // set active login logic option as a free setting
                    $options['activeLoginLogic'] = $active_login_logic;

                } else {

                    // if the user isn't premium, set the default option to 'automatic'
                    $options['activeLoginLogic'] = 'automatic';

                }

                update_option('persistent_login_options', $options);

            endif;
        endif;
                
        // update db version option
            update_option( 'persistent_login_db_version', '2.0.9');
            $persistent_login_db_version = '2.0.9';
            return true;
        
    endif; // 2.0.9 update

    
}

?>